diff mbox

[v2,12/27] mac80211: rename ieee80211_rx_flags to mac80211_i_rx_flags

Message ID 20110613223625.10517.59092.stgit@localhost6.localdomain6 (mailing list archive)
State Not Applicable, archived
Headers show

Commit Message

Kalle Valo June 13, 2011, 10:36 p.m. UTC
Add _i_ because, strangely enough,  mac80211_i.h already has another
definition of mac80211_rx_flags.

Signed-off-by: Kalle Valo <kvalo@adurom.com>
---
 net/mac80211/mac80211_i.h |    6 +++---
 net/mac80211/rx.c         |    4 ++--
 2 files changed, 5 insertions(+), 5 deletions(-)


--
To unsubscribe from this list: send the line "unsubscribe linux-wireless" in
the body of a message to majordomo@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
diff --git a/net/mac80211/rx.c b/net/mac80211/rx.c
index 12086b4..8245813 100644
--- a/net/mac80211/rx.c
+++ b/net/mac80211/rx.c
@@ -2394,9 +2394,9 @@  static void ieee80211_rx_cooked_monitor(struct ieee80211_rx_data *rx,
 	 * If cooked monitor has been processed already, then
 	 * don't do it again. If not, set the flag.
 	 */
-	if (rx->flags & IEEE80211_RX_CMNTR)
+	if (rx->flags & MAC80211_RX_CMNTR)
 		goto out_free_skb;
-	rx->flags |= IEEE80211_RX_CMNTR;
+	rx->flags |= MAC80211_RX_CMNTR;
 
 	if (skb_headroom(skb) < sizeof(*rthdr) &&
 	    pskb_expand_head(skb, sizeof(*rthdr), 0, GFP_ATOMIC))
diff mbox

Patch

diff --git a/net/mac80211/mac80211_i.h b/net/mac80211/mac80211_i.h
index 821d432..c33df24 100644
--- a/net/mac80211/mac80211_i.h
+++ b/net/mac80211/mac80211_i.h
@@ -183,15 +183,15 @@  enum mac80211_packet_rx_flags {
 };
 
 /**
  * enum ieee80211_rx_flags - RX data flags
  *
  * @MAC80211_RX_CMNTR: received on cooked monitor already
  *
  * These flags are used across handling multiple interfaces
  * for a single frame.
  */
-enum ieee80211_rx_flags {
-	IEEE80211_RX_CMNTR		= BIT(0),
+enum mac80211_i_rx_flags {
+	MAC80211_RX_CMNTR		= BIT(0),
 };
 
 struct ieee80211_rx_data {
@@ -183,15 +183,15 @@  enum mac80211_packet_rx_flags {
 
 /**
- * enum ieee80211_rx_flags - RX data flags
+ * enum mac80211_i_rx_flags - RX data flags
  *
  * @MAC80211_RX_CMNTR: received on cooked monitor already